@@ -2,13 +2,18 @@ from django import forms
 from django.utils.translation import ugettext_lazy as _
 from django.contrib.auth import authenticate
 from django.contrib.auth.models import User
+from django.utils.hashcompat import sha_constructor
 
 from userena import settings as userena_settings
 from userena.models import UserenaSignup
 from userena.utils import get_profile_model
 
+import random
+
 attrs_dict = {'class': 'required'}
 
+USERNAME_RE = r'^[\.\w]+$'
+
 class SignupForm(forms.Form):
     """
     Form for creating a new user account.
@@ -18,20 +23,20 @@ class SignupForm(forms.Form):
     be accepted.
 
     """
-    username = forms.RegexField(regex=r'^\w+$',
+    username = forms.RegexField(regex=USERNAME_RE,
                                 max_length=30,
                                 widget=forms.TextInput(attrs=attrs_dict),
                                 label=_("Username"),
-                                error_messages={'invalid': _('Username must contain only letters, numbers and underscores.')})
+                                error_messages={'invalid': _('Username must contain only letters, numbers, dots and underscores.')})
     email = forms.EmailField(widget=forms.TextInput(attrs=dict(attrs_dict,
                                                                maxlength=75)),
                              label=_("Email"))
     password1 = forms.CharField(widget=forms.PasswordInput(attrs=attrs_dict,
                                                            render_value=False),
-                                label=_("Password"))
+                                label=_("Create password"))
     password2 = forms.CharField(widget=forms.PasswordInput(attrs=attrs_dict,
                                                            render_value=False),
-                                label=_("Confirm password"))
+                                label=_("Repeat password"))
 
     def clean_username(self):
         """
@@ -77,33 +82,78 @@ class SignupForm(forms.Form):
         new_user = UserenaSignup.objects.create_inactive_user(username, email, password)
         return new_user
 
+class SignupFormOnlyEmail(SignupForm):
+    """
+    Form for creating a new user account but not needing a username.
+
+    This form is an adaptation of :class:`SignupForm`. It's used when
+    ``USERENA_WITHOUT_USERNAME`` setting is set to ``True``. And thus the user
+    is not asked to supply an username, but one is generated for them. The user
+    can than keep sign in by using their email.
+
+    """
+    def __init__(self, *args, **kwargs):
+        super(SignupFormOnlyEmail, self).__init__(*args, **kwargs)
+        del self.fields['username']
+
+    def save(self):
+        """ Generate a random username before falling back to parent signup form """
+        while True:
+            username = sha_constructor(str(random.random())).hexdigest()[:5]
+            try:
+                User.objects.get(username__iexact=username)
+            except User.DoesNotExist: break
+
+        self.cleaned_data['username'] = username
+        return super(SignupFormOnlyEmail, self).save()
+
 class SignupFormTos(SignupForm):
     """ Add a Terms of Service button to the ``SignupForm``. """
     tos = forms.BooleanField(widget=forms.CheckboxInput(attrs=attrs_dict),
                              label=_(u'I have read and agree to the Terms of Service'),
                              error_messages={'required': _('You must agree to the terms to register.')})
 
-class AuthenticationForm(forms.Form):
+def identification_field_factory(label, error_required):
     """
-    A custom ``AuthenticationForm`` where the identification can be a e-mail
-    address or username.
+    A simple identification field factory which enable you to set the label.
+
+    :param label:
+        String containing the label for this field.
+
+    :param error_required:
+        String containing the error message if the field is left empty.
 
     """
-    identification = forms.CharField(label=_("Email or username"),
-                                     widget=forms.TextInput(attrs=attrs_dict),
-                                     max_length=75,
-                                     error_messages={'required': _('Either supply us with your email or username.')})
+    return forms.CharField(label=_("%(label)s") % {'label': label},
+                           widget=forms.TextInput(attrs=attrs_dict),
+                           max_length=75,
+                           error_messages={'required': _("%(error)s") % {'error': error_required}})
+
+class AuthenticationForm(forms.Form):
+    """
+    A custom form where the identification can be a e-mail address or username.
+
+    """
+    identification = identification_field_factory(_(u"Email or username"),
+                                                  _(u"Either supply us with your email or username."))
     password = forms.CharField(label=_("Password"),
                                widget=forms.PasswordInput(attrs=attrs_dict, render_value=False))
     remember_me = forms.BooleanField(widget=forms.CheckboxInput(attrs=attrs_dict),
                                      required=False,
-                                     label=_(u'Remember me for %(days)s' % {'days': userena_settings.USERENA_REMEMBER_ME_DAYS[0]}))
+                                     label=_(u'Remember me for %(days)s') % {'days': _(userena_settings.USERENA_REMEMBER_ME_DAYS[0])})
+
+    def __init__(self, *args, **kwargs):
+        """ A custom init because we need to change the label if no usernames is used """
+        super(AuthenticationForm, self).__init__(*args, **kwargs)
+        if userena_settings.USERENA_WITHOUT_USERNAMES:
+            self.fields['identification'] = identification_field_factory(_(u"Email"),
+                                                                         _(u"Please supply your email."))
 
     def clean(self):
         """
         Checks for the identification and password.
 
-        If the combination can't be found will raise an invalid signin error.
+        If the combination can't be found will raise an invalid sign in error.
 
         """
         identification = self.cleaned_data.get('identification')
@@ -112,13 +162,13 @@ class AuthenticationForm(forms.Form):
         if identification and password:
             user = authenticate(identification=identification, password=password)
             if user is None:
-                raise forms.ValidationError(_("Please enter a correct username or email and password. Note that both fields are case-sensitive."))
+                raise forms.ValidationError(_(u"Please enter a correct username or email and password. Note that both fields are case-sensitive."))
         return self.cleaned_data
 
 class ChangeEmailForm(forms.Form):
     email = forms.EmailField(widget=forms.TextInput(attrs=dict(attrs_dict,
                                                                maxlength=75)),
-                             label=_("New email"))
+                             label=_(u"New email"))
 
     def __init__(self, user, *args, **kwargs):
         """
@@ -133,20 +183,17 @@ class ChangeEmailForm(forms.Form):
             raise TypeError, "user must be an instance of User"
         else: self.user = user
 
-        self.fields['email'].help_text = _('Your current email is %(email)s' % \
-                                           {'email': user.email})
-
     def clean_email(self):
         """ Validate that the email is not already registered with another user """
         if self.cleaned_data['email'].lower() == self.user.email:
-            raise forms.ValidationError(_('You\'re already known under this email.'))
+            raise forms.ValidationError(_(u'You\'re already known under this email.'))
         if User.objects.filter(email__iexact=self.cleaned_data['email']).exclude(email__iexact=self.user.email):
-            raise forms.ValidationError(_('This email is already in use. Please supply a different email.'))
+            raise forms.ValidationError(_(u'This email is already in use. Please supply a different email.'))
         return self.cleaned_data['email']
 
     def save(self):
         """
-        Save method calls ``user.change_email()`` method which sends out an
+        Save method calls :func:`user.change_email()` method which sends out an
         email with an verification key to verify and with it enable this new
         email address.
 
@@ -155,10 +202,10 @@ class ChangeEmailForm(forms.Form):
 
 class EditProfileForm(forms.ModelForm):
     """ Base form used for fields that are always required """
-    first_name = forms.CharField(label=_('First name'),
+    first_name = forms.CharField(label=_(u'First name'),
                                  max_length=30,
                                  required=False)
-    last_name = forms.CharField(label=_('Last name'),
+    last_name = forms.CharField(label=_(u'Last name'),
                                 max_length=30,
                                 required=False)
 
