@@ -6,6 +6,10 @@ from django.conf import settings
 gettext = lambda s: s
 
 
+USERENA_REDIRECT_ON_SIGNOUT = getattr(settings,
+                                      'USERENA_REDIRECT_ON_SIGNOUT',
+                                      None)
+
 USERENA_SIGNIN_REDIRECT_URL = getattr(settings,
                                       'USERENA_SIGNIN_REDIRECT_URL',
                                       '/accounts/%(username)s/')
@@ -36,12 +40,12 @@ USERENA_FORBIDDEN_USERNAMES = getattr(settings,
                                        'activate', 'me', 'password'))
 
 USERENA_MUGSHOT_GRAVATAR = getattr(settings,
-                                   'USERENA_USE_GRAVATAR',
+                                   'USERENA_MUGSHOT_GRAVATAR',
                                    True)
 
 USERENA_MUGSHOT_DEFAULT = getattr(settings,
-                                   'USERENA_MUGSHOT_DEFAULT',
-                                   'identicon')
+                                  'USERENA_MUGSHOT_DEFAULT',
+                                  'identicon')
 
 USERENA_MUGSHOT_SIZE = getattr(settings,
                                'USERENA_MUGSHOT_SIZE',
@@ -58,6 +62,7 @@ USERENA_USE_HTTPS = getattr(settings,
 USERENA_DEFAULT_PRIVACY = getattr(settings,
                                   'USERENA_DEFAULT_PRIVACY',
                                   'registered')
+
 USERENA_DISABLE_PROFILE_LIST = getattr(settings,
                                        'USERENA_DISABLE_PROFILE_LIST',
                                        False)
@@ -69,3 +74,7 @@ USERENA_USE_MESSAGES = getattr(settings,
 USERENA_LANGUAGE_FIELD = getattr(settings,
                                  'USERENA_LANGUAGE_FIELD',
                                  'language')
+
+USERENA_WITHOUT_USERNAMES = getattr(settings,
+                                    'USERENA_WITHOUT_USERNAMES',
+                                    False)
