@@ -86,6 +86,17 @@ class UserenaViewsTests(ProfileTestCase):
         self.failUnless(isinstance(response.context['form'],
                                    forms.SignupForm))
 
+        # Now check that a different form is used when
+        # ``USERENA_WITHOUT_USERNAMES`` setting is set to ``True``
+        userena_settings.USERENA_WITHOUT_USERNAMES = True
+
+        response = self.client.get(reverse('userena_signup'))
+        self.failUnless(isinstance(response.context['form'],
+                                   forms.SignupFormOnlyEmail))
+
+        # Back to default
+        userena_settings.USERENA_WITHOUT_USERNAMES = False
+
     def test_signup_view_success(self):
         """
         After a ``POST`` to the ``signup`` view a new user should be created,
@@ -128,7 +139,7 @@ class UserenaViewsTests(ProfileTestCase):
                                           'password': 'blowfish',
                                           'remember_me': True})
         self.assertEqual(self.client.session.get_expiry_age(),
-                         userena_settings.USERENA_REMEMBER_ME_DAYS[1] * 3600)
+                         userena_settings.USERENA_REMEMBER_ME_DAYS[1] * 3600 * 24)
 
     def test_signin_view_remember_off(self):
         """
