@@ -87,7 +87,7 @@ urlpatterns = patterns('',
        name='userena_profile_edit'),
 
     # View profiles
-    url(r'^(?P<username>(?![signout|signup|signin])[\.\w]+)/$',
+    url(r'^(?P<username>(?!signout|signup|signin)[\.\w]+)/$',
        userena_views.profile_detail,
        name='userena_profile_detail'),
     url(r'^page/(?P<page>[0-9]+)/$',
